pub enum RegistryRequest {
RegisterV1 {
process: Process,
threads_table_vmo: Vmo,
control_handle: RegistryControlHandle,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: RegistryControlHandle,
method_type: MethodType,
},
}Expand description
The Registry keeps track of all the instrumented processes.
Variants
RegisterV1
Binds the given process to the registry and share the relevant resources.
See //src/performance/memory/stacktrack/README.md and //src/performance/memory/stacktrack/lib/stacktrack_vmo for details on the format of the VMO.
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: RegistryControlHandle
method_type: MethodTypeImplementations
Sourceimpl RegistryRequest
impl RegistryRequest
pub fn into_register_v1(self) -> Option<(Process, Vmo, RegistryControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL